Module process

Module process 

Structs

Child
Representation of a child process spawned onto an event loop.
ChildStderr
The standard error stream for spawned children.
ChildStdin
The standard input stream for spawned children.
ChildStdout
The standard output stream for spawned children.
Command
This structure mimics the API of std::process::Command found in the standard library, but replaces functions that create a process with an asynchronous variant. The main provided asynchronous functions are spawn, status, and output.