Module process
chord_
core
0.1.21
Module process
Module Items
Structs
In chord_
core::
future
chord_core
::
future
Module
process
Structs

Child
Representation of a child process spawned onto an event loop.
Child
Stderr
The standard error stream for spawned children.
Child
Stdin
The standard input stream for spawned children.
Child
Stdout
The standard output stream for spawned children.
Command
This structure mimics the API of
std::process::Command
found in the standard library, but replaces functions that create a process with an asynchronous variant. The main provided asynchronous functions are
spawn
,
status
, and
output
.