Module value
Source - json
- Construct a
serde_json::Value from a JSON literal.
- Error
- This type represents all possible errors that can occur when serializing or
deserializing JSON data.
- Deserialize
- A data structure that can be deserialized from any data format supported
by Serde.
- Serialize
- A data structure that can be serialized into any data format supported
by Serde.
- from_reader
- Deserialize an instance of type
T from an I/O stream of JSON. - from_slice
- Deserialize an instance of type
T from bytes of JSON text. - from_str
- Deserialize an instance of type
T from a string of JSON text. - from_value
- Interpret a
serde_json::Value as an instance of type T. - map_merge_deep
- to_string
- Serialize the given data structure as a String of JSON.
- to_string_pretty
- Serialize the given data structure as a pretty-printed String of JSON.
- to_value
- Convert a
T into serde_json::Value which is an enum that can represent
any valid JSON data.
- Map
- Number
- Value
- Deserialize
- Serialize